@@ -19,11 +19,14 @@ from tkinter import (
     Frame,
     Button,
     Label,
+    Entry,
     Spinbox,
     Scale,
     Checkbutton,
     StringVar,
     IntVar,
+    N,
+    S,
     E,
     W,
     NORMAL,
@@ -60,7 +63,11 @@ from pygpsclient.globals import (
     KNOWNGPS,
     BPSRATES,
     FORMATS,
+    SOCKMODES,
     TAG_COLORS,
+    SOCKSERVER_PORT,
+    SOCKSERVER_NTRIP_PORT,
+    SOCKSERVER_MAX_CLIENTS,
 )
 from pygpsclient.helpers import valid_entry, VALINT, VALURL, MAXPORT
 from pygpsclient.strings import (
@@ -72,6 +79,10 @@ from pygpsclient.strings import (
     LBLTRACKRECORD,
     LBLSHOWUNUSED,
     LBLLEGEND,
+    LBLSOCKSERVE,
+    LBLSERVERPORT,
+    LBLDEGFORMAT,
+    LBLSERVERMODE,
 )
 
 TIMEOUTS = (
@@ -120,6 +131,10 @@ class SettingsFrame(Frame):
         self._show_unusedsat = IntVar()
         self._show_legend = IntVar()
         self._colortags = IntVar()
+        self._socket_serve = IntVar()
+        self._sock_port = StringVar()
+        self._sock_mode = StringVar()
+        self._sock_clients = StringVar()
         self._validsettings = True
         self._in_filepath = None
         self._logpath = None
@@ -228,7 +243,7 @@ class SettingsFrame(Frame):
             text="Tags",
             variable=self._colortags,
         )
-        self._lbl_format = Label(self._frm_options, text="Degrees Format")
+        self._lbl_format = Label(self._frm_options, text=LBLDEGFORMAT)
         self._spn_format = Spinbox(
             self._frm_options,
             values=(DDD, DMS, DMM),
@@ -303,6 +318,48 @@ class SettingsFrame(Frame):
             variable=self._record_track,
             command=lambda: self._on_record_track(),
         )
+        # socket server configuration
+        self._chk_socketserve = Checkbutton(
+            self._frm_options,
+            text=LBLSOCKSERVE,
+            variable=self._socket_serve,
+            command=lambda: self._on_socket_serve(),
+            state=DISABLED,
+        )
+        self._lbl_sockmode = Label(
+            self._frm_options,
+            text=LBLSERVERMODE,
+            state=DISABLED,
+        )
+        self._spn_sockmode = Spinbox(
+            self._frm_options,
+            values=SOCKMODES,
+            width=18,
+            state=DISABLED,
+            readonlybackground=ENTCOL,
+            wrap=True,
+            textvariable=self._sock_mode,
+            command=lambda: self._on_sockmode(),
+        )
+        self._lbl_sockport = Label(
+            self._frm_options,
+            text=LBLSERVERPORT,
+            state=DISABLED,
+        )
+        self._ent_sockport = Entry(
+            self._frm_options,
+            textvariable=self._sock_port,
+            bg=ENTCOL,
+            relief="sunken",
+            width=6,
+            state=DISABLED,
+        )
+        self._lbl_sockclients = Label(
+            self._frm_options,
+            textvariable=self._sock_clients,
+            state=DISABLED,
+        )
+        # configuration panel buttons
         self._lbl_ubxconfig = Label(self._frm_options, text=LBLUBXCONFIG)
         self._btn_ubxconfig = Button(
             self._frm_options,
@@ -389,14 +446,23 @@ class SettingsFrame(Frame):
         self._chk_recordtrack.grid(
             column=0, row=8, columnspan=2, padx=2, pady=2, sticky=(W)
         )
-
-        ttk.Separator(self._frm_options).grid(
-            column=0, row=9, columnspan=4, padx=2, pady=2, sticky=(W, E)
+        self._chk_socketserve.grid(
+            column=0, row=9, rowspan=2, padx=2, pady=2, sticky=(N, S, W)
         )
-        self._lbl_ubxconfig.grid(column=0, row=10, padx=2, pady=2, sticky=(E))
-        self._btn_ubxconfig.grid(column=1, row=10, padx=2, pady=2, sticky=(W))
-        self._lbl_ntripconfig.grid(column=2, row=10, padx=2, pady=2, sticky=(E))
-        self._btn_ntripconfig.grid(column=3, row=10, padx=2, pady=2, sticky=(W))
+        self._lbl_sockmode.grid(column=1, row=9, padx=2, pady=2, sticky=(E))
+        self._spn_sockmode.grid(
+            column=2, row=9, columnspan=2, padx=2, pady=2, sticky=(W)
+        )
+        self._lbl_sockport.grid(column=1, row=10, padx=2, pady=2, sticky=(E))
+        self._ent_sockport.grid(column=2, row=10, padx=2, pady=2, sticky=(W))
+        self._lbl_sockclients.grid(column=3, row=10, padx=2, pady=2, sticky=(W))
+        ttk.Separator(self._frm_options).grid(
+            column=0, row=11, columnspan=4, padx=2, pady=2, sticky=(W, E)
+        )
+        self._lbl_ubxconfig.grid(column=0, row=12, padx=2, pady=2, sticky=(E))
+        self._btn_ubxconfig.grid(column=1, row=12, padx=2, pady=2, sticky=(W))
+        self._lbl_ntripconfig.grid(column=2, row=12, padx=2, pady=2, sticky=(E))
+        self._btn_ntripconfig.grid(column=3, row=12, padx=2, pady=2, sticky=(W))
 
     def _on_ubx_config(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
@@ -504,10 +570,48 @@ class SettingsFrame(Frame):
             self.__app.conn_status = CONNECTED_FILE
             self.__app.stream_handler.start_read_thread(CONNECTED_FILE)
 
+    def _on_socket_serve(self):
+        """
+        Start or stop socket server.
+        """
+
+        if not valid_entry(self._ent_sockport, VALINT, 1, MAXPORT):
+            self.__app.set_status("ERROR - invalid port", "red")
+            self._socket_serve.set(0)
+            return
+
+        if self._socket_serve.get() == 1:
+            self.__app.start_sockserver_thread()
+            self._ent_sockport.config(state=DISABLED)
+            self._spn_sockmode.config(state=DISABLED)
+            self.__app.stream_handler.sock_serve = True
+        else:
+            self.__app.stop_sockserver_thread()
+            self._ent_sockport.config(state=NORMAL)
+            self._spn_sockmode.config(state=READONLY)
+            self.__app.stream_handler.sock_serve = False
+            self.clients = 0
+
+    def _on_sockmode(self):
+        """
+        Set default port depending on socket server mode.
+        """
+
+        if self._sock_mode.get() == SOCKMODES[1]:  # NTRIP Server
+            self._sock_port.set(SOCKSERVER_NTRIP_PORT)
+        else:
+            self._sock_port.set(SOCKSERVER_PORT)
+
     def _on_disconnect(self):
+        """
+        Disconnect from stream.
+        """
 
         if self.__app.conn_status in (CONNECTED, CONNECTED_FILE, CONNECTED_SOCKET):
             self.__app.stream_handler.stop_read_thread()
+            self.__app.stop_sockserver_thread()
+            self._socket_serve.set(0)
+            self.clients = 0
 
     def _reset(self):
         """
@@ -530,6 +634,10 @@ class SettingsFrame(Frame):
         self._record_track.set(False)
         self._logformat.set(FORMATS[1])  # Binary
         self._colortags.set(TAG_COLORS)
+        self._socket_serve.set(0)
+        self._sock_port.set(SOCKSERVER_PORT)
+        self._sock_mode.set(SOCKMODES[0])  # open
+        self.clients = 0
 
     def enable_controls(self, status: int):
         """
@@ -552,23 +660,22 @@ class SettingsFrame(Frame):
                 else NORMAL
             )
         )
-        self._btn_connect_socket.config(
-            state=(
-                DISABLED
-                if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
-                else NORMAL
+        for ctl in (
+            self._btn_connect_socket,
+            self._btn_connect_file,
+            self._chk_datalog,
+            self._chk_recordtrack,
+        ):
+            ctl.config(
+                state=(
+                    DISABLED
+                    if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
+                    else NORMAL
+                )
             )
-        )
         self._btn_disconnect.config(
             state=(DISABLED if status in (DISCONNECTED,) else NORMAL)
         )
-        self._chk_datalog.config(
-            state=(
-                DISABLED
-                if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
-                else NORMAL
-            )
-        )
         self._spn_datalog.config(
             state=(
                 DISABLED
@@ -576,18 +683,25 @@ class SettingsFrame(Frame):
                 else READONLY
             )
         )
-        self._chk_recordtrack.config(
-            state=(
-                DISABLED
-                if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
-                else NORMAL
+        for ctl in (
+            self._chk_socketserve,
+            self._ent_sockport,
+            self._lbl_sockport,
+            self._lbl_sockmode,
+            self._lbl_sockclients,
+        ):
+            ctl.config(
+                state=(
+                    NORMAL
+                    if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
+                    else DISABLED
+                )
             )
-        )
-        self._btn_connect_file.config(
+        self._spn_sockmode.config(
             state=(
-                DISABLED
+                READONLY
                 if status in (CONNECTED, CONNECTED_SOCKET, CONNECTED_FILE)
-                else NORMAL
+                else DISABLED
             )
         )
 
@@ -694,13 +808,13 @@ class SettingsFrame(Frame):
         return self._mapzoom.get()
 
     @property
-    def units(self) -> int:
+    def units(self) -> str:
         """
         Getter for display units
 
         :return: "UMM" = metric m/s, "UMK" = metric kmph,
                  "UI" = imperial mph, "UIK" = imperial knots
-        :rtype: int
+        :rtype: str
         """
 
         return self._units.get()
@@ -804,3 +918,74 @@ class SettingsFrame(Frame):
         """
 
         return self._show_legend.get()
+
+    @property
+    def server_state(self) -> int:
+        """
+        Getter for socket server run status.
+
+        :return: status 0 = off, 1 = on
+        :rtype: int
+        """
+
+        return self._socket_serve.get()
+
+    @server_state.setter
+    def server_state(self, status: int):
+        """
+        Setter for server run status.
+
+        :param int status: 0 = off, 1 = on
+        """
+
+        self._socket_serve.set(status)
+
+    @property
+    def server_port(self) -> int:
+        """
+        Getter for socket server port
+
+        :return: port
+        :rtype: int
+        """
+
+        return int(self._sock_port.get())
+
+    @property
+    def server_mode(self) -> int:
+        """
+        Getter for socket server mode
+
+        :return: 0 = open socket server, 1 = NTRIP server
+        :rtype: int
+        """
+
+        if self._sock_mode.get() == SOCKMODES[1]:  # "NTRIP SERVER"
+            return 1
+        return 0
+
+    @property
+    def clients(self) -> int:
+        """
+        Getter for number of socket clients.
+        """
+
+        return self._sock_clients.get()
+
+    @clients.setter
+    def clients(self, clients: int):
+        """
+        Setter for number of socket clients.
+
+        :param int clients: no of clients connected
+        """
+
+        self._sock_clients.set(f"Clients {clients}")
+        if clients >= SOCKSERVER_MAX_CLIENTS:
+            self._lbl_sockclients.config(fg="red")
+        elif clients == 0:
+            self._lbl_sockclients.config(fg="black")
+        else:
+            self._lbl_sockclients.config(fg="green")
+        if self._socket_serve.get() == 1:
+            self.__app.frm_banner.update_transmit_status(clients)
