@@ -287,7 +287,7 @@ class UBX_PRESET_Frame(Frame):
                 "CFG-TP5-TPX",
             ):
                 msg = UBXMessage("CFG", msgtype, POLL)
-                self.__app.serial_handler.serial_write(msg.serialize())
+                self.__app.stream_handler.serial_write(msg.serialize())
 
     def _do_poll_all_NAV(self):
         """
@@ -297,7 +297,7 @@ class UBX_PRESET_Frame(Frame):
         for msgtype in UBX_PAYLOADS_POLL:
             if msgtype[0:3] == "NAV":
                 msg = UBXMessage(msgtype.split("-")[0], msgtype, POLL)
-                self.__app.serial_handler.serial_write(msg.serialize())
+                self.__app.stream_handler.serial_write(msg.serialize())
 
     def _do_poll_prt(self):
         """
@@ -306,7 +306,7 @@ class UBX_PRESET_Frame(Frame):
 
         for portID in range(5):
             msg = UBXMessage("CFG", "CFG-PRT", POLL, portID=portID)
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
 
     def _do_poll_inf(self):
         """
@@ -315,7 +315,7 @@ class UBX_PRESET_Frame(Frame):
 
         for protid in (0, 1):  # UBX & NMEA
             msg = UBXMessage("CFG", "CFG-INF", POLL, protocolID=protid)
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
 
     def _do_set_inf(self, onoff: int):
         """
@@ -347,7 +347,7 @@ class UBX_PRESET_Frame(Frame):
                 + reserved2
             )
             msg = UBXMessage("CFG", "CFG-INF", SET, payload=payload)
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
             self._do_poll_inf()  # poll results
 
     def _do_set_log(self, msgrate: int):
@@ -458,10 +458,11 @@ class UBX_PRESET_Frame(Frame):
             msgID=msgID,
             rateDDC=msgrate,
             rateUART1=msgrate,
+            rateUART2=msgrate,
             rateUSB=msgrate,
             rateSPI=msgrate,
         )
-        self.__app.serial_handler.serial_write(msg.serialize())
+        self.__app.stream_handler.serial_write(msg.serialize())
 
     def _do_factory_reset(self) -> bool:
         """
@@ -484,7 +485,7 @@ class UBX_PRESET_Frame(Frame):
                 devFlash=1,
                 devEEPROM=1,
             )
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
             return True
 
         return False
@@ -510,7 +511,7 @@ class UBX_PRESET_Frame(Frame):
                 devFlash=1,
                 devEEPROM=1,
             )
-            self.__app.serial_handler.serial_write(msg.serialize())
+            self.__app.stream_handler.serial_write(msg.serialize())
             return True
 
         return False
@@ -538,7 +539,7 @@ class UBX_PRESET_Frame(Frame):
                     msg = UBXMessage(ubx_class, ubx_id, mode, payload=payload)
                 else:
                     msg = UBXMessage(ubx_class, ubx_id, mode)
-                self.__app.serial_handler.serial_write(msg.serialize())
+                self.__app.stream_handler.serial_write(msg.serialize())
         except Exception as err:  # pylint: disable=broad-except
             self.__app.set_status(f"Error {err}", "red")
             self._lbl_send_command.config(image=self._img_warn)
